(* ******************************************************************************************** *)
(* *                                                                     		              * *)
(* *                              X.25 Interface Library                                      * *)
(* *                              ----------------------                                      * *)
(* *                                                                     		              * *)
(* *                                    X25_Packet.h                                          * *)
(* *                                                                     		              * *)
(* *..........................................................................................* *)
(* *                                                                     		              * *)
(* *     X.25 Packet Format Definitions. 	  												  * *)
(* *                                                                     		              * *)
(* *                                                                     		              * *)
(* *------------------------------------------------------------------------------------------* *)
(* *                                                                     		              * *)
(* *                     Copyright Apple Computer, Inc. 1988-89                		          * *)
(* *                               All Rights Reserved                        		          * *)
(* *                           Apple Computer Confidential                     		          * *)
(* *                                                                     		              * *)
(* *------------------------------------------------------------------------------------------* *)
(* *                                                                     		              * *)
(* *     Revision History:                                               		              * *)
(* *                                                                     		              * *)
(* *     Date       Individual          Changes                                               * *)
(* *     .........  ................... ..................................................    * *)
(* *                                                                     		              * *)
(* *     15 Aug 88  D. N. Willey        Original Version                 		              * *)
(* *     01 Mar 88	James Beninghaus	Pascal Version                                        * *)
(* *                                                                     		              * *)
(* *                                                                     		              * *)
(* ******************************************************************************************** *)

    UNIT X25_Packet;
    INTERFACE    

(* ******************************************************************************************** *)
(* *                                                                                          * *)
(* *    General X.25 Packet Definitions                                                       * *)
(* *                                                                                          * *)
(* ******************************************************************************************** *)

CONST

(* +------------------------------------------------------------------------------------------+ *)
(* |                                                                                          | *)
(* |    Packet Types                                                                          | *)
(* |                                                                                          | *)
(* |..........................................................................................| *)
(* |                                                                                          | *)
(* |     	From DCE to DTE                         From DTE to DCE                           | *)
(* |                                                                                          | *)
(* +------------------------------------------------------------------------------------------+ *)

Incoming_Call				= $0B;
Call_Connected				= $0F;
Clear_Indication			= $13;
DCE_Clear_Confirmation		= $17;
Call_Request				= $0B;
Call_Accepted				= $0F;
Clear_Request				= $13;
DTE_Clear_Confirmation		= $17;

DCE_Data					= $00;
DCE_Interrupt				= $23;
DCE_Interrupt_Confirmation	= $27;
DTE_Data					= $00;
DTE_Interrupt				= $23;
DTE_Interrupt_Confirmation	= $27;

Reset_Indication			= $1B;
DCE_Reset_Confirmation		= $1F;
Reset_Request				= $1B;
DTE_Reset_Confirmation		= $1F;

Diagnostic					= $F1;

Registration_Confirmation	= $F7;
Registration_Request		= $F3;

(* ******************************************************************************************** *)
(* *                                                                                          * *)
(* *    Call Facility Codes                                                                   * *)
(* *                                                                                          * *)
(* ******************************************************************************************** *)

(* ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ *)
(* +                                                                     		              + *)
(* +	Call Facility Indicator Codes                                                         + *)
(* +                                                                       		              + *)
(* ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ *)
F_CUG_BASIC		= $03;		(* closed user group         - basic    (two digits)    *)
F_CUG_EXT		= $47;		(* closed user group         - extended (four digits)   *)
F_CUG_OA_BASIC	= $09;		(* cug with outgoing access  - basic    (two digits)    *)
F_CUG_OA_EXT	= $48;		(* cug with outgoing access  - extended (four digits)   *)
F_BCUG			= $41;		(* bilateral closed user group     						*)
F_REV_CHARG		= $01;		(* reverse charging                                     *)
F_RPOA			= $44;		(* RPOA transit netmork selection                       *)
F_CHARG_INFO	= $04;		(* charging information                                 *)
F_NUI			= $C6;		(* network user identification                          *)

(* ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ *)
(* +                                                                     		              + *)
(* +	Call Facility Bits                                                  		          + *)
(* +                                                                       		              + *)
(* ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ *)

FB_REV_CHARG	= $01;		(* bit indicating reverse charging                      *)
FB_FAST_SEL		= $80;		(* bit indicating fast select                      		*)
FB_FAST_SEL_R	= $C0;		(* bit indicating fast select restrictive          		*)
FB_CHARG_INFO	= $01;		(* bit indicating charging info requested          		*)


(* +------------------------------------------------------------------------------------------+ *)
(* |                                                                                          | *)
(* |    General Packet Mask Definition                                                   | *)
(* |                                                                                          | *)
(* +------------------------------------------------------------------------------------------+ *)

Q_Bit	=	$8000;
D_Bit	=	$4000;
Module	=	$3000;

TYPE

(* +------------------------------------------------------------------------------------------+ *)
(* |                                                                                          | *)
(* |    General Packet Structure Definition                                                   | *)
(* |                                                                                          | *)
(* +------------------------------------------------------------------------------------------+ *)

packet	= PACKED RECORD
	formatID	: INTEGER;					(* General Format Identifier          (left nibble) *)
											(*     Qualified Data Transmission		            *)
											(*     Delivery Confirmation Notification		    *)
											(*     Sequence Number Modulo		                *)
											(* Logical Channel Group Number		 (right nibble) *)
											(* Logical Channel Number		                    *)
	pht_type	: BYTE;						(* Packet Type Identifier						    *)
	pkt_data	: ARRAY [1 .. 1] OF BYTE;	(* Begining of the Variable Packet Data Field	    *)
END;

(* ******************************************************************************************** *)
(* *                                                                                          * *)
(* *    End                                                                                   * *)
(* *                                                                                          * *)
(* ******************************************************************************************** *)


IMPLEMENTATION

END.